@@ -55,7 +55,7 @@ class DistributedScheduler(object):
     extract = None  # the tld extractor
     hits = 0  # default number of hits for a queue
     window = 0  # default window to calculate number of hits
-    my_ip = '127.0.0.1'  # the ip address of the scheduler (if needed)
+    my_ip = None  # the ip address of the scheduler (if needed)
     old_ip = None  # the old ip for logging
     signals = None  # scrapy signals
     ip_update_interval = 0  # the interval to update the ip address
@@ -307,10 +307,10 @@ class DistributedScheduler(object):
             obj.close()
             self.logger.debug("Current public ip: {ip}".format(ip=self.my_ip))
 
-            if self.old_ip != self.my_ip:
+            if self.old_ip is not None and self.old_ip != self.my_ip:
                 self.logger.info("Changed Public IP: {old} -> {new}".format(
                     old=self.old_ip, new=self.my_ip))
-                if self.old_ip != '127.0.0.1' and self.my_ip != '52.28.30.162':
+                if self.my_ip != '52.28.30.162':
                     self.signals.send_catch_log_deferred(signal=bhf_signals.ip_changed)
         except IOError:
             self.logger.error("Could not reach out to get public ip")
