@@ -130,7 +130,7 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
 
     async def _create_browser_context(self, name: str, context_kwargs: dict) -> BrowserContext:
         context = await self.browser.new_context(**context_kwargs)
-        # context.on("close", self._make_close_browser_context_callback(name))
+        context.on("close", self._make_close_browser_context_callback(name))
         logger.debug("Browser context started: '%s'", name)
         self.stats.inc_value("playwright/context_count")
         if self.default_navigation_timeout is not None:
@@ -171,7 +171,7 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
         if self.default_navigation_timeout is not None:
             page.set_default_navigation_timeout(self.default_navigation_timeout)
 
-        page.on("close", self._make_close_page_callback("default"))
+        # page.on("close", self._make_close_page_callback("default"))
         page.on("crash", self._make_close_page_callback("default"))
         page.on("request", _make_request_logger("default"))
         page.on("response", _make_response_logger("default"))
@@ -236,21 +236,22 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
                 ),
             )
 
-            logger.info(f"[{request.url}] After route")
             result = await self._download_request_with_page(request, page)
         except:
             logger.exception(f"[{request.url}] Error while downloading request")
+            return Response('', status=504)
         else:
             logger.info(f"[{request.url}] Return result")
             return result
         finally:
-            logger.info(f"[{request.url}] Finally")
-            if not page.is_closed():
-                await page.close()
+            if page is not None:
+                if not page.is_closed():
+                    await page.close()
+                    self.context_semaphores['default'].release()
 
     async def _download_request_with_page(self, request: Request, page: Page) -> Response:
         start_time = time()
-        response = await page.goto(request.url, wait_until="commit")
+        response = await page.goto(request.url, wait_until="domcontentloaded")
 
         logger.info(f"[{request.url}] After goto")
         await self._apply_page_methods(page, request)
