@@ -1,6 +1,9 @@
 from scrapy.downloadermiddlewares.retry import RetryMiddleware
 
 
+unserializable_meta_params = ['playwright_page_methods']
+
+
 class RedisRetryMiddleware(RetryMiddleware):
 
     def __init__(self, settings):
@@ -10,12 +13,14 @@ class RedisRetryMiddleware(RetryMiddleware):
         retries = request.meta.get('retry_times', 0) + 1
         if retries <= self.max_retry_times:
             retryreq = request.copy()
+            # remove unserializable parameters
+            for unserializable_meta_param in unserializable_meta_params:
+                if unserializable_meta_param in retryreq.meta:
+                    del retryreq.meta[unserializable_meta_param]
+            # add params
             retryreq.meta['retry_times'] = retries
             retryreq.dont_filter = True
-            # our priority setup is different from super
+            # low priority
             retryreq.meta['priority'] = retryreq.meta['priority'] - 10
 
-            if 'playwright_page_methods' in retryreq.meta:
-                del retryreq.meta['playwright_page_methods']
-
             return retryreq
